#!/usr/bin/env python

"""Tests for `cap2_assembly` package."""


import unittest
from click.testing import CliRunner

# from cap2_assembly import cap2_assembly # Uncomment when tests written
from cap2_assembly import cli


class TestCap2_assembly(unittest.TestCase):
    """Tests for `cap2_assembly` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""

    def test_command_line_interface(self):
        """Test the CLI."""
        runner = CliRunner()
        result = runner.invoke(cli.main)
        assert result.exit_code == 0
        assert 'cap2_assembly.cli.main' in result.output
        help_result = runner.invoke(cli.main, ['--help'])
        assert help_result.exit_code == 0
        assert '--help  Show this message and exit.' in help_result.output
